#!/usr/bin/perl -wT
#
# Copyright (C) 2003,2004 Robert van den Aker <robert2@dds.nl>
# This script uses functions that are copyright (C) 2002 Mitel Networks
# Corporation.
# This script was largely yanked and put from the qmailanalog script in
# SME Server 5.5.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 		
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 		
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307,
# USA.
# 
#----------------------------------------------------------------------
 
package esmith::FormMagick::Panel::printanalyzer;
 
use strict;
use esmith::FormMagick;
use Exporter;
our @ISA = qw(esmith::FormMagick Exporter);
our @EXPORT = qw(generateReport);
 
=pod
 
=head1 NAME
 
esmith::FormMagick::Panel::printanalyzer - PrintAnalyzer panel functions
 
=head1 SYNOPSIS
 
	use esmith::FormMagick::Panel::printanalyzer;
	my $panel = esmith::FormMagick::Panel::printanalyzer->new();
	$panel->display();
 
=head1 DESCRIPTION

=head2 new ();
 
Exactly as for esmith::FormMagick
 
=cut
 
sub new
{
	shift;
	my $self = esmith::FormMagick->new();
	$self->{calling_package} = (caller)[0];
	bless $self;
	return $self;
}


=pod

=head2 generateReport

Generate and display the PrintAnalyzer report.

=cut

sub generateReport
{
	my $self = shift;
	my $q = $self->{cgi};

	# This snippet attempts to set the system locale variables to
	# match the browser language settings so that the date can be
	# displayed in a localised way. It isn't perfect, because I
	# don't know any easy way to convert languages to locale tags,
	# but it seems to work reasonably well. [charlieb; from the SME
	# 5.5 qmailanalog panel]

	use POSIX qw(setlocale strftime LC_ALL);
	my ($lang) = $self->get_languages();
	$lang =~ tr/-/_/;
	if ($lang =~ /(\w\w)_(\w+)/)
	{
	  $lang = "$1_".uc($2);
	}
	setlocale(LC_ALL, $lang);
	my $now_string = strftime "%c", localtime;
	print $q->h3($self->localise('REPORT_GENERATED'), $now_string);

	my $current_log = "/var/log/cups/page_log";
	my $previous_log = "$current_log.1";
	if (-f $previous_log)
	{
	  my $last_rotate = strftime "%c", localtime((stat($previous_log))[9]);
	  print $q->p($self->localise('START_REPORT_PERIOD'), $last_rotate);
	}
	elsif (open (PAGELOG, "<$current_log"))
	{
	  while (<PAGELOG>)
	  {
	    /\[(.*)\]/ &&
	    print $q->p($self->localise('START_REPORT_PERIOD'), $1);
	    last;
	  }
	  close (PAGELOG);
	}

	if (-r $current_log)
	{
	  open(CUPSPAGEREPORT, "/usr/bin/PrintAnalyzer |");
	  print "<pre>\n";
	  print while (<CUPSPAGEREPORT>);
	  close CUPSPAGEREPORT;
	  print "</pre>\n";
	}
	else
	{
	  print $q->p($self->localise('NO_CURRENT_LOG'));
	}

	print $q->h3($self->localise('END_OF_REPORT'));
	return '';
}


1;
